#!/bin/bash -
# supermin
# (C) Copyright 2014 Red Hat Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

set -e

# Test the basic run of supermin
../src/supermin --help

# Very simple test for the version string
../src/supermin --version | grep ^supermin

# Check that listing drivers work
../src/supermin --list-drivers

# Check at least one driver is detected
echo
../src/supermin --list-drivers | grep -v not-detected
